@@ -1,5 +1,7 @@
 from ml_solutions import solutions
 from ml_solutions import neuralnet
+from ml_solutions import algorithms
 
 __author__ = "Debadrito Dutta"
-__email__ = "dipalidutta312@gmail.com"
\ No newline at end of file
+__email__ = "dipalidutta312@gmail.com"
+__version__ = "0.0.3"
\ No newline at end of file
